Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(539)

Unified Diff: chrome/browser/tab_contents/tab_contents_view_gtk.h

Issue 507022: Fix issue 11258: Linux: gracefully handle small browser window... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gtk/tabs/tab_strip_gtk.cc ('k') | chrome/browser/tab_contents/tab_contents_view_gtk.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/tab_contents/tab_contents_view_gtk.h
===================================================================
--- chrome/browser/tab_contents/tab_contents_view_gtk.h (revision 34953)
+++ chrome/browser/tab_contents/tab_contents_view_gtk.h (working copy)
@@ -89,22 +89,30 @@
static gboolean OnMouseDown(GtkWidget* widget,
GdkEventButton* event, TabContentsViewGtk* view);
- // Used to propagate size changes on |fixed_| to its children.
- static gboolean OnSizeAllocate(GtkWidget* widget,
- GtkAllocation* config,
+ // Used to adjust the size of its children when the size of |expanded_| is
+ // changed.
+ static void OnChildSizeRequest(GtkWidget* widget,
+ GtkWidget* child,
+ GtkRequisition* requisition,
TabContentsViewGtk* view);
+ // Used to propagate the size change of |expanded_| to our RWHV to resize the
+ // renderer content.
+ static void OnSizeAllocate(GtkWidget* widget,
+ GtkAllocation* allocation,
+ TabContentsViewGtk* view);
+
static void OnSetFloatingPosition(
GtkFloatingContainer* floating_container, GtkAllocation* allocation,
TabContentsViewGtk* tab_contents_view);
// Contains |fixed_| as its GtkBin member and a possible floating widget from
// |popup_view_|.
OwnedWidgetGtk floating_;
- // This container holds the tab's web page views. It is a GtkFixed so that we
- // can control the size of the web pages.
- GtkWidget* fixed_;
+ // This container holds the tab's web page views. It is a GtkExpandedContainer
+ // so that we can control the size of the web pages.
+ GtkWidget* expanded_;
// The context menu is reset every time we show it, but we keep a pointer to
// between uses so that it won't go out of scope before we're done with it.
« no previous file with comments | « chrome/browser/gtk/tabs/tab_strip_gtk.cc ('k') | chrome/browser/tab_contents/tab_contents_view_gtk.cc » ('j') | no next file with comments »
@@ -89,22 +89,30 @@
GtkFloatingContainer* floating_container, GtkAllocation* allocation,
TabContentsViewGtk* tab_contents_view);
- // Contains |fixed_| as its GtkBin member and a possible floating widget from
- // |popup_view_|.
+ // Contains |expanded_| as its GtkBin member and a possible floating widget
+ // from |popup_view_|.
OwnedWidgetGtk floating_;

Powered by Google App Engine
This is Rietveld 408576698